@@ -153,6 +153,9 @@ class Mentor(Model):
     skills = models.TextField(blank=True, null=True, verbose_name="What skills can you share with our entrepreneurs ?")
 
     fields = models.ManyToManyField(Field, blank=True)
+    organisationName = models.CharField(max_length=256, blank=True, null=True, verbose_name='Organisation name, to get info on unexisting ones')
+    organisationContact = models.CharField(max_length=256, blank=True, null=True, verbose_name='Organisation contact, to get info on unexisting ones')
+    headline = models.CharField(max_length=256, blank=True, null=True, verbose_name='Headline or current position')
 
     linkedin = models.CharField(max_length=256, null=True, blank=True, verbose_name='Linkedin account')
     twitter = models.CharField(max_length=256, null=True, blank=True, verbose_name='Twitter account')
